@@ -1,5 +1,5 @@
-use std::fs;
-use std::path::Path;
+use std::path::PathBuf;
+use std::{env, fs};
 
 fn process_json(data: &serde_json::Value) -> serde_json::Value {
     let mut out_data = serde_json::Map::new();
@@ -14,9 +14,25 @@ fn process_json(data: &serde_json::Value) -> serde_json::Value {
 }
 
 fn main() {
-    let version_metadata = "download-metadata.json";
-    println!("cargo::rerun-if-changed={version_metadata}");
-    let target = Path::new("src/download-metadata-minified.json");
+    let version_metadata = PathBuf::from_iter([
+        env::var("CARGO_MANIFEST_DIR").unwrap(),
+        "download-metadata.json".into(),
+    ]);
+
+    let version_metadata_minified = PathBuf::from_iter([
+        env::var("OUT_DIR").unwrap(),
+        "download-metadata-minified.json".into(),
+    ]);
+
+    println!(
+        "cargo::rerun-if-changed={}",
+        version_metadata.to_str().unwrap()
+    );
+
+    println!(
+        "cargo::rerun-if-changed={}",
+        version_metadata_minified.to_str().unwrap()
+    );
 
     let json_data: serde_json::Value = serde_json::from_str(
         #[allow(clippy::disallowed_methods)]
@@ -28,7 +44,7 @@ fn main() {
 
     #[allow(clippy::disallowed_methods)]
     fs::write(
-        target,
+        version_metadata_minified,
         serde_json::to_string(&filtered_data).expect("Failed to serialize JSON"),
     )
     .expect("Failed to write minified JSON");
