@@ -474,6 +474,9 @@ impl EnvVars {
     /// General proxy for all network requests.
     pub const ALL_PROXY: &'static str = "ALL_PROXY";
 
+    /// Comma-separated list of hostnames (e.g., `example.com`) and/or patterns (e.g., `192.168.1.0/24`) that should bypass the proxy.
+    pub const NO_PROXY: &'static str = "NO_PROXY";
+
     /// Timeout (in seconds) for HTTP requests. (default: 30 s)
     pub const UV_HTTP_TIMEOUT: &'static str = "UV_HTTP_TIMEOUT";
 
@@ -494,12 +497,15 @@ impl EnvVars {
     /// Used to detect an activated virtual environment.
     pub const VIRTUAL_ENV: &'static str = "VIRTUAL_ENV";
 
-    /// Used to detect an activated Conda environment.
+    /// Used to detect the path of an active Conda environment.
     pub const CONDA_PREFIX: &'static str = "CONDA_PREFIX";
 
-    /// Used to determine if an active Conda environment is the base environment or not.
+    /// Used to determine the name of the active Conda environment.
     pub const CONDA_DEFAULT_ENV: &'static str = "CONDA_DEFAULT_ENV";
 
+    /// Used to determine the root install path of Conda.
+    pub const CONDA_ROOT: &'static str = "_CONDA_ROOT";
+
     /// If set to `1` before a virtual environment is activated, then the
     /// virtual environment name will not be prepended to the terminal prompt.
     pub const VIRTUAL_ENV_DISABLE_PROMPT: &'static str = "VIRTUAL_ENV_DISABLE_PROMPT";
@@ -531,6 +537,18 @@ impl EnvVars {
     /// Defaults to `13.0`, the least-recent non-EOL macOS version at time of writing.
     pub const MACOSX_DEPLOYMENT_TARGET: &'static str = "MACOSX_DEPLOYMENT_TARGET";
 
+    /// Used with `--python-platform arm64-apple-ios` and related variants to set the
+    /// deployment target (i.e., the minimum supported iOS version).
+    ///
+    /// Defaults to `13.0`.
+    pub const IPHONEOS_DEPLOYMENT_TARGET: &'static str = "IPHONEOS_DEPLOYMENT_TARGET";
+
+    /// Used with `--python-platform aarch64-linux-android` and related variants to set the
+    /// Android API level. (i.e., the minimum supported Android API level).
+    ///
+    /// Defaults to `24`.
+    pub const ANDROID_API_LEVEL: &'static str = "ANDROID_API_LEVEL";
+
     /// Disables colored output (takes precedence over `FORCE_COLOR`).
     ///
     /// See [no-color.org](https://no-color.org).
@@ -609,14 +627,17 @@ impl EnvVars {
     #[attr_hidden]
     pub const GIT_CEILING_DIRECTORIES: &'static str = "GIT_CEILING_DIRECTORIES";
 
-    /// Used for trusted publishing via `uv publish`.
+    /// Indicates that the current process is running in GitHub Actions.
+    ///
+    /// `uv publish` may attempt trusted publishing flows when set
+    /// to `true`.
     pub const GITHUB_ACTIONS: &'static str = "GITHUB_ACTIONS";
 
-    /// Used for trusted publishing via `uv publish`. Contains the oidc token url.
-    pub const ACTIONS_ID_TOKEN_REQUEST_URL: &'static str = "ACTIONS_ID_TOKEN_REQUEST_URL";
-
-    /// Used for trusted publishing via `uv publish`. Contains the oidc request token.
-    pub const ACTIONS_ID_TOKEN_REQUEST_TOKEN: &'static str = "ACTIONS_ID_TOKEN_REQUEST_TOKEN";
+    /// Indicates that the current process is running in GitLab CI.
+    ///
+    /// `uv publish` may attempt trusted publishing flows when set
+    /// to `true`.
+    pub const GITLAB_CI: &'static str = "GITLAB_CI";
 
     /// Sets the encoding for standard I/O streams (e.g., PYTHONIOENCODING=utf-8).
     #[attr_hidden]
@@ -641,6 +662,18 @@ impl EnvVars {
     #[attr_hidden]
     pub const CI: &'static str = "CI";
 
+    /// Azure DevOps build identifier, used to detect CI environments.
+    #[attr_hidden]
+    pub const BUILD_BUILDID: &'static str = "BUILD_BUILDID";
+
+    /// Generic build identifier, used to detect CI environments.
+    #[attr_hidden]
+    pub const BUILD_ID: &'static str = "BUILD_ID";
+
+    /// Pip environment variable to indicate CI environment.
+    #[attr_hidden]
+    pub const PIP_IS_CI: &'static str = "PIP_IS_CI";
+
     /// Use to set the .netrc file location.
     pub const NETRC: &'static str = "NETRC";
 
@@ -753,16 +786,12 @@ impl EnvVars {
     #[attr_hidden]
     pub const KEYRING_TEST_CREDENTIALS: &'static str = "KEYRING_TEST_CREDENTIALS";
 
-    /// Used to set the vendor links url for tests.
-    #[attr_hidden]
-    pub const UV_TEST_VENDOR_LINKS_URL: &'static str = "UV_TEST_VENDOR_LINKS_URL";
-
     /// Used to disable delay for HTTP retries in tests.
     pub const UV_TEST_NO_HTTP_RETRY_DELAY: &'static str = "UV_TEST_NO_HTTP_RETRY_DELAY";
 
-    /// Used to set an index url for tests.
+    /// Used to set a packse index url for tests.
     #[attr_hidden]
-    pub const UV_TEST_INDEX_URL: &'static str = "UV_TEST_INDEX_URL";
+    pub const UV_TEST_PACKSE_INDEX: &'static str = "UV_TEST_PACKSE_INDEX";
 
     /// Used for testing named indexes in tests.
     #[attr_hidden]
@@ -857,6 +886,11 @@ impl EnvVars {
     /// Disable Hugging Face authentication, even if `HF_TOKEN` is set.
     pub const UV_NO_HF_TOKEN: &'static str = "UV_NO_HF_TOKEN";
 
+    /// The URL to treat as an S3-compatible storage endpoint. Requests to this endpoint
+    /// will be signed using AWS Signature Version 4 based on the `AWS_ACCESS_KEY_ID`,
+    /// `AWS_SECRET_ACCESS_KEY`, `AWS_PROFILE`, and `AWS_CONFIG_FILE` environment variables.
+    pub const UV_S3_ENDPOINT_URL: &'static str = "UV_S3_ENDPOINT_URL";
+
     /// The URL of the pyx Simple API server.
     pub const PYX_API_URL: &'static str = "PYX_API_URL";
 
@@ -879,4 +913,34 @@ impl EnvVars {
 
     /// Specifies the directory where uv stores pyx credentials.
     pub const PYX_CREDENTIALS_DIR: &'static str = "PYX_CREDENTIALS_DIR";
+
+    /// The AWS region to use when signing S3 requests.
+    pub const AWS_REGION: &'static str = "AWS_REGION";
+
+    /// The default AWS region to use when signing S3 requests, if `AWS_REGION` is not set.
+    pub const AWS_DEFAULT_REGION: &'static str = "AWS_DEFAULT_REGION";
+
+    /// The AWS access key ID to use when signing S3 requests.
+    pub const AWS_ACCESS_KEY_ID: &'static str = "AWS_ACCESS_KEY_ID";
+
+    /// The AWS secret access key to use when signing S3 requests.
+    pub const AWS_SECRET_ACCESS_KEY: &'static str = "AWS_SECRET_ACCESS_KEY";
+
+    /// The AWS session token to use when signing S3 requests.
+    pub const AWS_SESSION_TOKEN: &'static str = "AWS_SESSION_TOKEN";
+
+    /// The AWS profile to use when signing S3 requests.
+    pub const AWS_PROFILE: &'static str = "AWS_PROFILE";
+
+    /// The AWS config file to use when signing S3 requests.
+    pub const AWS_CONFIG_FILE: &'static str = "AWS_CONFIG_FILE";
+
+    /// The AWS shared credentials file to use when signing S3 requests.
+    pub const AWS_SHARED_CREDENTIALS_FILE: &'static str = "AWS_SHARED_CREDENTIALS_FILE";
+
+    /// Avoid verifying that wheel filenames match their contents when installing wheels. This
+    /// is not recommended, as wheels with inconsistent filenames should be considered invalid and
+    /// corrected by the relevant package maintainers; however, this option can be used to work
+    /// around invalid artifacts in rare cases.
+    pub const UV_SKIP_WHEEL_FILENAME_CHECK: &'static str = "UV_SKIP_WHEEL_FILENAME_CHECK";
 }
